#!/bin/sh
# Run as . dev-setup.sh to set up paths
# for testing in current directory
base=`pwd`
export PATH
export PYTHONPATH
PYTHONPATH=$base
PATH=$base/scripts:$base/scripts/pegasus:$base/scripts/utilities:$PATH

